@@ -2,7 +2,7 @@ package Mojolicious::Plugin::RoutesConfig;
 use Mojo::Base 'Mojolicious::Plugin::Config', -signatures;
 use List::Util qw(first);
 
-our $VERSION   = 0.06;
+our $VERSION   = 0.07;
 our $AUTHORITY = 'cpan:BEROV';
 
 sub register {
@@ -26,7 +26,7 @@ sub register {
 # generates routes (recursively for under)
 sub _generate_routes {
   my ($self, $app, $routes, $routes_conf, $file_msg) = @_;
-  my $init_rx = '^(?:any|route|get|post|patch|put|delete|options|under)$';
+  my $init_rx = '^(?:any|get|post|patch|put|delete|options|under)$';
   for my $rconf (@$routes_conf) {
     my $init_method = first(sub { $_ =~ /$init_rx/; }, keys %$rconf);
     unless ($init_method) {
@@ -77,7 +77,10 @@ sub _call_method ($caller, $method, $params) {
     return $caller->$method($params);
   }
 
-  Carp::croak('This should never happen');
+  Carp::confess("Paramether to $method "
+    . "must be one of ARRAY, HASH, CODE reference or scalar in the form controller#action. "
+    . "Now it is "
+    . Mojo::Util::dumper($params));
 }
 
 =encoding utf8
@@ -106,7 +109,7 @@ Mojolicious::Plugin::RoutesConfig - Describe routes in configuration
     ],
   }
 
-  # Mojolicious
+  # in YourApp::startup()
   my $config = $app->plugin('Config');
   # or even
   my $config = $app->plugin('RoutesConfig');
@@ -115,7 +118,7 @@ Mojolicious::Plugin::RoutesConfig - Describe routes in configuration
   $app->plugin('RoutesConfig', {file => $app->home->child('etc/routes_admin.conf')});
   $app->plugin('RoutesConfig', {file => $app->home->child('etc/routes_site.conf')});
 
-  # Mojolicious::Lite
+  # in  YourLiteApp
   my $config = plugin 'Config';
   plugin 'RoutesConfig', $config;
   plugin 'RoutesConfig', {file => app->home->child('etc/routes_admin.conf')};
@@ -166,17 +169,9 @@ LICENSE file included with this module.
 
 =head1 SEE ALSO
 
-L<Mojolicious::Guides::Routing>, L<Mojolicious::Routes>,
-L<Mojolicious::Routes::Route>, L<Mojolicious::Plugin::Config>
-
-L<Slovo> has a pretty advanced routes configuration using
-L<Mojolicious::Plugin::RoutesConfig>.  Please look at
-Slovo/lib/Slovo/resources/etc/routes.conf.
+L<Mojolicious::Routes>, L<Mojolicious::Routes::Route>, L<Mojolicious::Plugin::Config>
 
 =cut
 
-#################### main pod documentation end ###################
-
-
 1;
 
